@@ -63,12 +63,12 @@ class SystemIPSwitches:
         self.systembash.run_protect()
         self.systemctl.protect_ctl_enable()
 
-    def switch_vpn(self, granular: bool = True):
-        self.systemd.openvpn(granular)
+    def switch_vpn(self, granular: bool = False, netclass: str = "C"):
+        self.systemd.openvpn(granular=granular, netclass=netclass)
         self.systembash.run_vpn4()
         self.systemctl.openvpn_ctl_enable()
 
-    def switch_docker(self, granular: bool = True):
+    def switch_docker(self, granular: bool = False):
         self.systemd.docker(granular)
         self.systembash.run_docker()
         self.systemctl.docker_ctl_enable()
@@ -174,22 +174,22 @@ class SystemD:
         self.systemdfiles.writebash(protect_bash_filepath, protect_bashtext)
         self.systemdfiles.writeservice(protect_service_filepath, protect_servicetext)
 
-    def openvpn(self, granular: bool = True):
+    def openvpn(self, granular: bool = False, netclass: str = "C"):
         vpn_service_filepath, vpn_servicetext = self.service_unit_text.openvpn()
         if granular:
             (
                 vpn_bash_filepath,
                 vpn_bashtext,
-            ) = self.service_bash_text.vpnkillswitch_g_text()
+            ) = self.service_bash_text.vpnkillswitch_g_text(netclass=netclass)
         else:
             (
                 vpn_bash_filepath,
                 vpn_bashtext,
-            ) = self.service_bash_text.vpnkillswitch_text()
+            ) = self.service_bash_text.vpnkillswitch_text(netclass=netclass)
         self.systemdfiles.writebash(vpn_bash_filepath, vpn_bashtext)
         self.systemdfiles.writeservice(vpn_service_filepath, vpn_servicetext)
 
-    def docker(self, granular: bool = True):
+    def docker(self, granular: bool = False):
         docker_service_filepath, docker_servicetext = self.service_unit_text.docker()
         if granular:
             (
@@ -274,6 +274,7 @@ class SystemdFiles:
         self.erase(self.systemdfilepaths.vpn4_service)
         self.erase(self.systemdfilepaths.docker_bash)
         self.erase(self.systemdfilepaths.docker_service)
+        self.erase(self.systemdfilepaths.nuke_bash)
 
 
 class ServiceUnitTexts:
@@ -552,7 +553,7 @@ create_filter_rule 'iptables -A OUTPUT -m state --state INVALID -j DROP'
 create_filter_chain 'RB_I_RELATED_AND_ESTABLISHED'
 create_filter_rule 'iptables -A RB_I_RELATED_AND_ESTABLISHED -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
 create_filter_rule 'iptables -A RB_I_RELATED_AND_ESTABLISHED -p udp --sport 53 -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
-create_filter_rule 'iptables -A RB_I_RELATED_AND_ESTABLISHED -i lo -p udp --dport 53 -m conntrack --ctstate NEW,ESTABLISHED -j ACCEPT'
+create_filter_rule 'iptables -A RB_I_RELATED_AND_ESTABLISHED -i lo -p udp --dport 53 -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
 create_filter_rule 'iptables -I INPUT -j RB_I_RELATED_AND_ESTABLISHED'
 create_filter_chain 'RB_O_RELATED_AND_ESTABLISHED'
 create_filter_rule 'iptables -A RB_O_RELATED_AND_ESTABLISHED -m conntrack --ctstate NEW,RELATED,ESTABLISHED -j ACCEPT'
@@ -566,7 +567,13 @@ sysctl_file_disable_ipv6
 """
         return self.systemdfilepaths.protect_bash, text
 
-    def vpnkillswitch_text(self):
+    def vpnkillswitch_text(self, netclass: str = "C"):
+        if netclass == "C":
+            netclassip = "192.168.0.0/16"
+        if netclass == "B":
+            netclassip = "172.16.0.0/12"
+        if netclass == "A":
+            netclassip = "10.0.0.0/8"
         text = f"""#!/bin/bash
 {self.bashfunctions}
 {self.procfunctions}
@@ -574,8 +581,12 @@ sysctl_file_disable_ipv6
 iptables --policy INPUT DROP
 iptables --policy FORWARD DROP
 iptables --policy OUTPUT DROP
+create_filter_rule 'iptables -A INPUT -m state --state INVALID -j DROP'
+create_filter_rule 'iptables -A FORWARD -m state --state INVALID -j DROP'
+create_filter_rule 'iptables -A OUTPUT -m state --state INVALID -j DROP'
 create_filter_chain 'RB_I_RELATED_AND_ESTABLISHED'
 create_filter_rule 'iptables -A RB_I_RELATED_AND_ESTABLISHED -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
+create_filter_rule 'iptables -A RB_I_RELATED_AND_ESTABLISHED  -i lo -j ACCEPT '
 create_filter_rule 'iptables -I INPUT  -j RB_I_RELATED_AND_ESTABLISHED'
 #let's create a chain named RB_OUTPUT_VPN_KILL_SWITCH to hold our VPN rules
 create_filter_chain 'RB_OUTPUT_VPN_KILL_SWITCH'
@@ -584,7 +595,7 @@ create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -o tun+ -j ACCEPT'
 create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -o lo -j ACCEPT'
 #If you want to, you can also allow access to your local network.
 #The most common local network is class C, 192.168.0.0/16
-create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -d 10.0.0.0/8 -j ACCEPT'
+create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -d {netclassip} -j ACCEPT'
 #You must check what local network class you car connected to.
 #Adjust for Class C, 192.168.0.0/16 Class B, 172.16.0.0/12 and class A 10.0.0.0/8
 #The following line is to allow a single ip address for your DNS server, 
@@ -599,7 +610,13 @@ sysctl_file_disable_ipv6
 """
         return self.systemdfilepaths.vpn4_bash, text
 
-    def vpnkillswitch_g_text(self):
+    def vpnkillswitch_g_text(self, netclass: str = "C"):
+        if netclass == "C":
+            netclassip = "192.168.0.0/16"
+        if netclass == "B":
+            netclassip = "172.16.0.0/12"
+        if netclass == "A":
+            netclassip = "10.0.0.0/8"
         text = f"""#!/bin/bash
 {self.bashfunctions}
 {self.procfunctions}
@@ -607,9 +624,13 @@ sysctl_file_disable_ipv6
 iptables --policy INPUT DROP
 iptables --policy FORWARD DROP
 iptables --policy OUTPUT DROP
+create_filter_rule 'iptables -A INPUT -m state --state INVALID -j DROP'
+create_filter_rule 'iptables -A FORWARD -m state --state INVALID -j DROP'
+create_filter_rule 'iptables -A OUTPUT -m state --state INVALID -j DROP'
 #Create a custom chain to contain rules to allow related and established traffic.
 create_filter_chain 'RB_I_RELATED_AND_ESTABLISHED'
 create_filter_rule 'iptables -A RB_I_RELATED_AND_ESTABLISHED -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
+create_filter_rule 'iptables -A RB_I_RELATED_AND_ESTABLISHED  -i lo -j ACCEPT '
 #Divert input traffic to the RB_I_RELATED_AND_ESTABLISHED chain.
 create_filter_rule 'iptables -I INPUT -j RB_I_RELATED_AND_ESTABLISHED'
 #Let's allow the loopback device.
@@ -632,7 +653,7 @@ create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -o lo -j ACCEPT'
 create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -o tun+ -p icmp -j ACCEPT'
 #If you want to, you can also allow access to your local network.
 #The most common local network is class C, 192.168.0.0/16
-create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -d 10.0.0.0/8 -j ACCEPT'
+create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -d {netclassip} -j ACCEPT'
 #You must check what local network class you car connected to.
 #Adjust for Class C, 192.168.0.0/16 Class B, 172.16.0.0/12 and class A 10.0.0.0/8
 #The following line is to allow a single ip address for your DNS server, 
